@@ -12,22 +12,24 @@ osType <- function() {
   if ( ( ! grepl("^x86", info["machine"]) ) || ( ! ( sysname %in% c("Windows","Darwin","Linux") ) ) ) sprintf("%s-%s",info["sysname"],info["machine"])
   else if ( sysname == "Windows" ) "windows"
   else if ( sysname == "Darwin" ) "macosx"
+  else if ( sysname == "Darwin-arm64") "macosx-arm"
   else if ( sysname == "Linux" ) "linux"
   else sysname
 }
 osType <- osType()
 
-if(!(osType %in% c('windows', 'macosx', 'linux'))){
+if(!(osType %in% c('windows', 'macosx', 'linux', 'macosx-arm'))){
   cat(paste0(osType, ' is not a supported platform.\n',
-             'Please use baseflow package with Windows, GNU/Linux or Mac OS.\n'))
-  quit(status = 1)
+             'Compilation and installation may be possible if the Rust compiler is available.\n',
+             'It is recommended to use baseflow package with Windows, GNU/Linux or macOS.\n'))
+  #quit(status = 1)
 }
 
 # Detecting cargo installed version
 requiredCargoVersion <- "1.42.0"
 cat(paste0("Cargo version ", requiredCargoVersion, " or newer is required for compilation.\n"))
 
-if(!cargo_is_found && (osType == 'linux')){
+if(!cargo_is_found && !(osType %in% c("windows", "macosx", "macosx-arm"))){
   cat("Cargo is a requirement to compile the Rust library. Please visit https://rustup.rs to install it. You do not need admin rights.\n")
   quit(status = 1)
 }
@@ -35,7 +37,7 @@ if(cargo_is_found && (osType == 'windows')){
   installedCargoVersion <- gsub("cargo ([^ ]+).*", "\\1", system2("cargo","--version",stdout=TRUE))
   cat(paste0("Cargo version ", installedCargoVersion, " found.\n"))
   installedCargoVersion <- strsplit(installedCargoVersion, '-')[[1]][1]
-  is_installed_newer <- (compareVersion(installedCargoVersion, requiredCargoVersion) > 0)
+  is_installed_newer <- (compareVersion(installedCargoVersion, requiredCargoVersion) >= 0)
   
   # Compiling if cargo version is OK
   if(is_installed_newer){
@@ -51,7 +53,7 @@ if(cargo_is_found && (osType != 'windows')){
   installedCargoVersion <- gsub("cargo ([^ ]+).*", "\\1", system2("cargo","--version",stdout=TRUE))
   cat(paste0("Cargo version ", installedCargoVersion, " found.\n"))
   installedCargoVersion <- strsplit(installedCargoVersion, '-')[[1]][1]
-  is_installed_newer <- (compareVersion(installedCargoVersion, requiredCargoVersion) > 0)
+  is_installed_newer <- (compareVersion(installedCargoVersion, requiredCargoVersion) >= 0)
   
   # Compiling if cargo version is OK
   if(is_installed_newer){
@@ -88,6 +90,24 @@ if(!cargo_is_found && (osType == 'macosx')){
     file.remove(paste0('./ext_tools/', target, '/release/', f))
   }
 }
+if(!cargo_is_found && (osType == 'macosx-arm')){
+  target <- "aarch64-apple-darwin"
+  cat("Downloading pre-compiled Rust library.\n")
+  download.file('https://gitlab.irstea.fr/HYCAR-Hydro/baseflow/-/raw/master/tools/tools.tar.gz',
+                destfile = 'tools.tar.gz')
+  dir.create('./ext_tools')
+  untar('tools.tar.gz', list = FALSE, exdir = './ext_tools')
+  
+  destDir <- "rustlib/target/release"
+  dir.create(destDir, recursive = TRUE)
+  
+  files_list <- c('librustlib.d', 'librustlib.rlib', 'librustlib.a')
+  for(f in files_list){
+    file.copy(from = paste0('./ext_tools/', target, '/release/', f),
+              to = paste0(destDir, '/', f), overwrite = TRUE)
+    file.remove(paste0('./ext_tools/', target, '/release/', f))
+  }
+}
 if(!cargo_is_found && (osType == 'windows')){
   cat("Downloading pre-compiled Rust library.\n")
   download.file('https://gitlab.irstea.fr/HYCAR-Hydro/baseflow/-/raw/master/tools/tools.tar.gz',
